@@ -8,22 +8,20 @@ utm33n <- st_crs(25833)
 wgs <- st_crs(4326)
 
 test_that("General tests", {
-    
-    # smaller extent (crop)
-    if (Sys.info()["nodename"] == "pvil-r") {
+    if (Sys.info()["nodename"] == "pvil-rr.bafg.de") {
         # input data
         filename_dem <- paste0("/home/WeberA/freigaben/U/U3/Auengruppe_INFORM/",
-                               "RH_336_867_UFD/data/ascii/r002_PLITTERSDORF1_D",
-                               "EM.asc")
+                               "RH_336_867_UFD/data/asc/r002_PLITTERSDORF1_DEM",
+                               ".asc")
         filename_csa <- paste0("/home/WeberA/freigaben/U/U3/Auengruppe_INFORM/",
-                               "RH_336_867_UFD/data/ascii/r002_PLITTERSDORF1_C",
-                               "SA.asc")
+                               "RH_336_867_UFD/data/asc/r002_PLITTERSDORF1_CSA",
+                               ".asc")
         ext <- ext(436500, 438000, 5415000, 5416500)
         
         # tests
         expect_message(a <- hydSpatRaster(filename_dem, filename_csa, ext,
                                           crs = utm32n),
-                       "'ext' will be used to crop the supplied raster file(s).",
+                       "'ext' will be used to crop the supplied raster file(s)",
                        fixed = TRUE)
         # expect_message(b <- hydSpatRaster(filename_csa = filename_csa, 
         #                                    ext = ext, crs = utm32n),
@@ -107,10 +105,10 @@ test_that("General tests", {
                      "crs must be either 'ETRS 1989 UTM 32N' or 'ETRS 1989 UTM 33N")
         expect_error(hydSpatRaster(ext = ext(200000, 201000, 5749000, 5749500),
                                    crs = crs_csa),
-                     "does NOT overlap with the active floodplain of River Elbe")
+                     "does NOT overlap with the active floodplain of River Elb")
         expect_error(hydSpatRaster(ext = ext(200000, 201000, 5749000, 5749500),
                                    crs = utm32n),
-                     "does NOT overlap with the active floodplain of River Rhine")
+                     "does NOT overlap with the active floodplain of River Rh")
         
         unlink(tmp_dem1)
         unlink(tmp_dem2)
@@ -130,4 +128,3 @@ test_that("General tests", {
                  "'filename_csa' must have length 1")
     
 })
-
